@@ -1,15 +1,14 @@
-/**********************************************************************************
+/*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2014 NAN contributors
+ * Copyright (c) 2015 NAN contributors
  *
- * MIT +no-false-attribs License <https://github.com/rvagg/nan/blob/master/LICENSE>
- **********************************************************************************/
+ * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ ********************************************************************/
 
-#include <node.h>
 #include <nan.h>
-#include "./pi_est.h"
-#include "./sync.h"
+#include "pi_est.h"  // NOLINT(build/include)
+#include "sync.h"  // NOLINT(build/include)
 
 using v8::Number;
 
