@@ -1,13 +1,20 @@
-/**********************************************************************************
+/*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2014 NAN contributors
+ * Copyright (c) 2015 NAN contributors
  *
- * MIT +no-false-attribs License <https://github.com/rvagg/nan/blob/master/LICENSE>
- **********************************************************************************/
+ * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ ********************************************************************/
 
 #include <nan.h>
-#include <string>
+#if defined(_MSC_VER)
+# pragma warning( push )
+# pragma warning( disable : 4530 )
+# include <string>
+# pragma warning( pop )
+#else
+# include <string>
+#endif
 
 static int magic = 1337;
 
@@ -26,6 +33,11 @@ NAN_METHOD(NewPositiveInteger) {
   NanReturnValue(NanNew<v8::Integer>(1));
 }
 
+NAN_METHOD(NewUnsignedInteger) {
+  NanScope();
+  NanReturnValue(NanNew<v8::Integer>(0xFFFFFFFFu));
+}
+
 NAN_METHOD(NewInt32FromPositive) {
   NanScope();
   NanReturnValue(NanNew<v8::Int32>(0xFFFFFFFF));
@@ -101,7 +113,7 @@ NAN_METHOD(NewSignature) {
   NanScope();
   v8::Local<v8::FunctionTemplate> tmpl =
       NanNew<v8::FunctionTemplate>(NewSignature);
-  v8::Local<v8::Signature> sig = NanNew<v8::Signature>(tmpl, 1, &tmpl);
+  v8::Local<v8::Signature> sig = NanNew<v8::Signature>(tmpl);
   tmpl = NanNew<v8::FunctionTemplate>(
       NewSignature, v8::Handle<v8::Value>(), sig);
   NanReturnValue(NanNew<v8::String>("string"));
@@ -144,6 +156,26 @@ NAN_METHOD(NewArray) {
   NanReturnValue(NanNew<v8::Array>());
 }
 
+NAN_METHOD(NewBoolean) {
+  NanScope();
+  NanReturnValue(NanNew<v8::Boolean>(true));
+}
+
+// #212
+NAN_METHOD(NewBoolean2) {
+  NanScope();
+
+#if defined(_MSC_VER)
+# pragma warning( push )
+# pragma warning( disable : 4800 )
+#endif
+  NanReturnValue(NanNew<v8::Boolean>(1));
+#if defined(_MSC_VER)
+# pragma warning( pop )
+#endif
+
+}
+
 void Init(v8::Handle<v8::Object> target) {
   target->Set(
       NanNew<v8::String>("newNumber")
@@ -157,6 +189,10 @@ void Init(v8::Handle<v8::Object> target) {
       NanNew<v8::String>("newPositiveInteger")
     , NanNew<v8::FunctionTemplate>(NewPositiveInteger)->GetFunction()
   );
+  target->Set(
+      NanNew<v8::String>("newUnsignedInteger")
+    , NanNew<v8::FunctionTemplate>(NewUnsignedInteger)->GetFunction()
+  );
   target->Set(
       NanNew<v8::String>("newInt32FromPositive")
     , NanNew<v8::FunctionTemplate>(NewInt32FromPositive)->GetFunction()
@@ -237,6 +273,14 @@ void Init(v8::Handle<v8::Object> target) {
       NanNew<v8::String>("newArray")
     , NanNew<v8::FunctionTemplate>(NewArray)->GetFunction()
   );
+  target->Set(
+      NanNew<v8::String>("newBoolean")
+    , NanNew<v8::FunctionTemplate>(NewBoolean)->GetFunction()
+  );
+  target->Set(
+      NanNew<v8::String>("newBoolean2")
+    , NanNew<v8::FunctionTemplate>(NewBoolean2)->GetFunction()
+  );
 }
 
 NODE_MODULE(news, Init)
