@@ -1,10 +1,10 @@
-/**********************************************************************************
+/*********************************************************************
  * NAN - Native Abstractions for Node.js
  *
- * Copyright (c) 2014 NAN contributors
+ * Copyright (c) 2015 NAN contributors
  *
- * MIT +no-false-attribs License <https://github.com/rvagg/nan/blob/master/LICENSE>
- **********************************************************************************/
+ * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ ********************************************************************/
 
 #include <nan.h>
 
@@ -31,10 +31,22 @@ NAN_METHOD(HeapString) {
   NanReturnValue(res);
 }
 
+NAN_METHOD(EncodeHex) {
+  NanScope();
+  NanReturnValue(NanEncode("hello", 5, Nan::HEX));
+}
+
+NAN_METHOD(EncodeUCS2) {
+  NanScope();
+  NanReturnValue(NanEncode("h\0e\0l\0l\0o\0", 10, Nan::UCS2));
+}
+
 v8::Persistent<v8::FunctionTemplate> returnAsciiString_persistent;
 v8::Persistent<v8::FunctionTemplate> returnUtf8String_persistent;
 v8::Persistent<v8::FunctionTemplate> returnUcs2String_persistent;
 v8::Persistent<v8::FunctionTemplate> heapString_persistent;
+v8::Persistent<v8::FunctionTemplate> encodeHex_persistent;
+v8::Persistent<v8::FunctionTemplate> encodeUCS2_persistent;
 
 void Init (v8::Handle<v8::Object> target) {
   NanScope();
@@ -90,6 +102,32 @@ void Init (v8::Handle<v8::Object> target) {
       NanNew("heapString")
     , heapString->GetFunction()
   );
+
+  v8::Local<v8::FunctionTemplate> encodeHex =
+    NanNew<v8::FunctionTemplate>(EncodeHex);
+
+  NanAssignPersistent(
+    encodeHex_persistent
+  , encodeHex
+  );
+
+  target->Set(
+      NanNew("encodeHex")
+    , encodeHex->GetFunction()
+  );
+
+  v8::Local<v8::FunctionTemplate> encodeUCS2 =
+    NanNew<v8::FunctionTemplate>(EncodeUCS2);
+
+  NanAssignPersistent(
+    encodeUCS2_persistent
+  , encodeUCS2
+  );
+
+  target->Set(
+      NanNew("encodeUCS2")
+    , encodeUCS2->GetFunction()
+  );
 }
 
 NODE_MODULE(strings, Init)
