@@ -1,12 +1,21 @@
+/*********************************************************************
+ * NAN - Native Abstractions for Node.js
+ *
+ * Copyright (c) 2015 NAN contributors
+ *
+ * MIT License <https://github.com/rvagg/nan/blob/master/LICENSE.md>
+ ********************************************************************/
+
 const test     = require('tap').test
     , testRoot = require('path').resolve(__dirname, '..')
     , bindings = require('bindings')({ module_root: testRoot, bindings: 'news' });
 
 test('news', function (t) {
-  t.plan(46);
+  t.plan(52);
   t.type(bindings.newNumber, 'function');
   t.type(bindings.newPositiveInteger, 'function');
   t.type(bindings.newNegativeInteger, 'function');
+  t.type(bindings.newUnsignedInteger, 'function');
   t.type(bindings.newInt32FromPositive, 'function');
   t.type(bindings.newInt32FromNegative, 'function');
   t.type(bindings.newUint32FromPositive, 'function');
@@ -27,10 +36,13 @@ test('news', function (t) {
   t.type(bindings.compileScript2, 'function');
   t.type(bindings.newDate, 'function');
   t.type(bindings.newArray, 'function');
+  t.type(bindings.newBoolean, 'function');
+  t.type(bindings.newBoolean2, 'function');
 
   t.equal(bindings.newNumber(), 0.5);
   t.equal(bindings.newPositiveInteger(), 1);
   t.equal(bindings.newNegativeInteger(), -1);
+  t.equal(bindings.newUnsignedInteger(), 0xFFFFFFFF);
   t.equal(bindings.newInt32FromPositive(), -1);
   t.equal(bindings.newInt32FromNegative(), -1);
   t.equal(bindings.newUint32FromPositive(), 0xFFFFFFFF);
@@ -51,4 +63,6 @@ test('news', function (t) {
   t.equals(bindings.compileScript2(), 6);
   t.deepEquals(bindings.newDate(), new Date(1337));
   t.deepEquals(bindings.newArray(), []);
+  t.equal(bindings.newBoolean(), true);
+  t.equal(bindings.newBoolean2(), true);
 });
